@@ -41,11 +41,9 @@
 #include <glib.h>
 #include <glib-object.h>
 #include <conic.h>
-/* #include <libintl.h>
-#include <locale.h>
-*/
 
 void dbus_connection_setup_with_g_main (DBusConnection *connection, GMainContext *context);
+
 //#define DEBUG_PRINTF
 
 #ifdef DEBUG_PRINTF
@@ -55,10 +53,7 @@ void dbus_connection_setup_with_g_main (DBusConnection *connection, GMainContext
 #endif
 
 #define VERSION "1.0"
-/* #define LOCALEDIR "/usr/share/locale" */
 #define GETTEXT_PACKAGE "tabletbridge"
-/* #define LC_ALL "en" */
-/* #define _(String) gettext(String) */
 #define _(String) String
 #define DEST_PORT 5555
 #define SCAN_PORT 3483
@@ -132,7 +127,7 @@ static int sockfd;
  * 34 character offset + 3 for additional /r/n characters
  * total 4133, this could be calculated depending on the screen size to allow for
  * easy additions of new screens */
-static char packet[4352]; // rounded to a 256k boundary
+static char packet[4352]; // rounded to a 256 byte boundary
 static unsigned int activity_counter;
 
 /** VARIABLES PERTAINING TO THE INTERNET CONNECTION. */
@@ -183,13 +178,13 @@ static void update_pixbuf(char *display)
     int rowstride, n_channels, i, j, k, l, m, bit, display_ptr;
     unsigned int nibble;
     guchar *pixels, *p, red, green, blue;
-    
+
     my_printf("%s()\n", __PRETTY_FUNCTION__);
-    
+
     rowstride = gdk_pixbuf_get_rowstride (pixbuf);
     pixels = gdk_pixbuf_get_pixels (pixbuf);
     n_channels = gdk_pixbuf_get_n_channels (pixbuf);
-    
+
     display_ptr = 0;
     for (i=0; i<displays[display_idx].width; i++) { /* columns */
       for (j=0; j<displays[display_idx].height/4; j++) {
@@ -229,9 +224,9 @@ static void update_pixbuf(char *display)
  	} /* for k */
       } /* for j */
     } /* for i */
-    
+
     gtk_image_set_from_pixbuf((GtkImage *)screen, pixbuf);
-        
+
     my_printf("%s(): return TRUE\n", __PRETTY_FUNCTION__);
 }
 
@@ -252,26 +247,29 @@ static char *get_response(char *search, int offset)
     gint ptr, ret;
     gchar *display_ptr;
     gboolean found_start=FALSE, found_end=FALSE;
-    
+
     my_printf("%s()\n", __PRETTY_FUNCTION__);
     ptr=0;
     memset(packet, 0, sizeof(packet));
-    
+
     if (connected == FALSE)
       return NULL;
-    
+
     /* get response */
     do {
       my_printf("sizeof(packet)-ptr=%d\n", sizeof(packet)-ptr);
-      
+
       ret = recv(sockfd, packet+ptr, sizeof(packet)-ptr, 0);
       if (ret == -1) {
         hildon_banner_show_information(GTK_WIDGET(window), NULL,
                              "get_response recv failed");
-        close(sockfd);
+        if (sockfd != -1) {
+		close(sockfd);
+		sockfd = -1;
+	}
         return NULL;
       }
-      
+
       my_printf("ret = %d\n", ret);
 
       ptr += ret;
@@ -287,7 +285,7 @@ static char *get_response(char *search, int offset)
       my_printf(packet);
       my_printf("%s(): return NULL\n", __PRETTY_FUNCTION__);
       return NULL;
-    }      
+    }
     my_printf("%s(): return\n", __PRETTY_FUNCTION__);
     return (display_ptr+offset);
 }
@@ -295,16 +293,19 @@ static char *get_response(char *search, int offset)
 static gint send_request(char *msg)
 {
     gint len, bytes_sent=0;
-    
+
     my_printf("%s()\n", __PRETTY_FUNCTION__);
-    
+
     if (connected == TRUE) {
       len = strlen(msg);
       bytes_sent = send(sockfd, msg, len, 0);
       if (bytes_sent == -1) {
         hildon_banner_show_information(GTK_WIDGET(window), NULL,
                              "send_request: send failure");
-        close(sockfd);
+        if (sockfd != -1) {
+		close(sockfd);
+		sockfd = -1;
+	}
         return -1;
       }
       if (bytes_sent != len) {
@@ -319,7 +320,7 @@ static gint send_request(char *msg)
 
 static gboolean query_type(void)
 {
-    gchar *msg = "ListVisualizers\n";
+    gchar *msg = "ListVisualizers\r\n";
     gint len, bytes_sent = 0, ptr, ret, offset=0, lines_found=0, lines_expected=0;
     gchar *display_ptr, *search = "ListVisualizers: ListResultSize ", *end;
     gboolean found_start=FALSE;
@@ -352,7 +353,10 @@ static gboolean query_type(void)
         if (ret == -1) {
           hildon_banner_show_information(GTK_WIDGET(window), NULL,
                              "query_type: recv failed");
-          close(sockfd);
+          if (sockfd != -1) {
+		  close(sockfd);
+		  sockfd = -1;
+	  }
           return FALSE;
         }
         my_printf("ret = %d\n", ret);
@@ -405,7 +409,7 @@ static gboolean query_type(void)
 
 static gboolean periodic_update(gpointer data)
 {
-    char *msg = "GetDisplayData\n";
+    char *msg = "GetDisplayData\r\n";
     char *screen_data;
     
     my_printf("%s()\n", __PRETTY_FUNCTION__);
@@ -449,19 +453,35 @@ static gboolean periodic_update(gpointer data)
     return TRUE;
 }
 
+void *get_in_addr(struct sockaddr *sa)
+{
+	if (sa->sa_family == AF_INET) {
+		return &(((struct sockaddr_in*)sa)->sin_addr);
+	}
+
+	return &(((struct sockaddr_in6*)sa)->sin6_addr);
+}
+
 static gboolean periodic_scan(gpointer data)
 {
     char msg[] = "Scanning |\0";
     unsigned char twirl;
-    struct sockaddr_in from;
-    int fromlen, recvlen;
-    char buf[128];
-    
+    struct sockaddr_storage from;
+    socklen_t fromlen;
+    int recvlen;
+    char buf[64];
+    char s[INET6_ADDRSTRLEN];
+
     my_printf("%s()\n", __PRETTY_FUNCTION__);
-    
-    if (scan_info.currently_scanning == FALSE)
-      return FALSE;
-    
+
+    if (scan_info.currently_scanning == FALSE) {
+	    if (scan_info.sockfd != -1) {
+		    close(scan_info.sockfd);
+		    scan_info.sockfd = -1;
+	    }
+	    return FALSE;
+    }
+
     if (_iap_connected == FALSE) {
       hildon_banner_show_information(GTK_WIDGET(window), NULL,
                              "Not connected");
@@ -474,8 +494,9 @@ static gboolean periodic_scan(gpointer data)
       /* got data from recvfrom */
       GtkTreeIter iter;
       gboolean valid, present = FALSE;
-        
-      my_printf("got packet from %s\n", inet_ntoa(from.sin_addr));
+
+      inet_ntop(from.ss_family, get_in_addr((struct sockaddr *)&from), s, sizeof(s));
+      my_printf("got packet from %s\n",s);
       my_printf("packet is %d bytes long\n", recvlen);
       /* Make sure duplicates don't get added */
       valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(scan_info.store), &iter);
@@ -485,7 +506,7 @@ static gboolean periodic_scan(gpointer data)
         gtk_tree_model_get(GTK_TREE_MODEL(scan_info.store), &iter, 0, 
                            &name_data, 1, &ip_data, -1);
         my_printf("name = %s, ip = %s\n", name_data, ip_data);
-        if (strcmp(inet_ntoa(from.sin_addr), ip_data) == 0) {
+        if (strcmp(s, ip_data) == 0) {
           present = TRUE;
           g_free(name_data);
           g_free(ip_data);
@@ -495,31 +516,34 @@ static gboolean periodic_scan(gpointer data)
         g_free(ip_data);
         valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(scan_info.store), &iter);
       } /* while (valid) */
-      
+
       /* It's not a duplicate */
       if (present == FALSE) {
         struct sockaddr_in dest_addr;
         struct timeval tv = {3, 0}; /* 3 sec, 0 usec */
-        gchar *friendly_rqst = "GetFriendlyName\n";
+        gchar *friendly_rqst = "GetFriendlyName\r\n";
         gchar *friendly_name;
 
         /* Get the friendly name */
         /* clear out from previous connections */
-        close(sockfd);
+        if (sockfd != -1) {
+		close(sockfd);
+		sockfd = -1;
+	}
         clear_pixbuf();
         gtk_frame_set_label(GTK_FRAME(frame),
                             _("Soundbridge Display - Not connected"));
         connected = FALSE;
-    
+
         /* make a connection */
         sockfd = socket(PF_INET, SOCK_STREAM, 0);
-    
+
         if (sockfd == -1) {
           hildon_banner_show_information(GTK_WIDGET(window), NULL,
                            "periodic_scan: Unable to get socket");
           goto try_next_sb;
         }
-    
+
         if (setsockopt(sockfd, SOL_SOCKET, SO_RCVTIMEO, &tv, sizeof(tv)) < 0) {
           hildon_banner_show_information(GTK_WIDGET(window), NULL,
                         "periodic_scan: O_RCVTIMEO setsockopt error");
@@ -531,9 +555,9 @@ static gboolean periodic_scan(gpointer data)
 
         dest_addr.sin_family = AF_INET;          // host byte order
         dest_addr.sin_port = htons(DEST_PORT);   // short, network byte order
-        dest_addr.sin_addr.s_addr = inet_addr(inet_ntoa(from.sin_addr));
+        dest_addr.sin_addr.s_addr = inet_addr(s);
         memset(dest_addr.sin_zero, '\0', sizeof dest_addr.sin_zero);
-    
+
         if (connect(sockfd, (struct sockaddr *)&dest_addr, sizeof dest_addr) == -1) {
           hildon_banner_show_information(GTK_WIDGET(window), NULL,
                            "periodic_scan: Unable to connect");
@@ -548,20 +572,23 @@ static gboolean periodic_scan(gpointer data)
         friendly_name = get_response("GetFriendlyName:", 17);
         if (friendly_name != NULL) {
           friendly_name[strlen(friendly_name)-2] = '\0';
-        
+
           gtk_list_store_append(scan_info.store, &iter);
           gtk_list_store_set(scan_info.store, &iter,
                 0, g_strdup(friendly_name),
-                1, g_strdup(inet_ntoa(from.sin_addr)),
+                1, g_strdup(s),
                 -1);
         }
 try_next_sb:
         connected = FALSE;
-        close(sockfd);
+        if (sockfd != -1) {
+		close(sockfd);
+		sockfd = -1;
+	}
       } /* if (present == FALSE) */
 
     } /* got data from recvfrom */
-    
+
     switch (scan_info.progress%4) {
       case 0:
         twirl = '|';
@@ -580,10 +607,10 @@ try_next_sb:
         break;
     }
     scan_info.progress++;
-    
+
     sprintf(msg, "Scanning %c", twirl);
     gtk_window_set_title(GTK_WINDOW(scan_info.scan_dialog), msg);
-    
+
     my_printf("%s(): return TRUE\n", __PRETTY_FUNCTION__);
     return TRUE;
 }
@@ -599,32 +626,32 @@ window_cb_key_press(GtkWidget* widget, GdkEventKey *event)
     if (connected == TRUE) {
       switch(event->keyval)
       {
-          case HILDON_HARDKEY_UP:
-              send_request("IrDispatchCommand CK_NORTH\n");
+          case GDK_Up:
+              send_request("IrDispatchCommand CK_NORTH\r\n");
               break;
-          case HILDON_HARDKEY_DOWN:
-              send_request("IrDispatchCommand CK_SOUTH\n");
+          case GDK_Down:
+              send_request("IrDispatchCommand CK_SOUTH\r\n");
               break;
-          case HILDON_HARDKEY_LEFT:
-              send_request("IrDispatchCommand CK_WEST\n");
+          case GDK_Left:
+              send_request("IrDispatchCommand CK_WEST\r\n");
               break;
-          case HILDON_HARDKEY_RIGHT:
-              send_request("IrDispatchCommand CK_EAST\n");
+          case GDK_Right:
+              send_request("IrDispatchCommand CK_EAST\r\n");
               break;
-          case HILDON_HARDKEY_SELECT:
-              send_request("IrDispatchCommand CK_SELECT\n");
+          case GDK_Return:
+              send_request("IrDispatchCommand CK_SELECT\r\n");
               break;
-          case HILDON_HARDKEY_INCREASE:
-              send_request("IrDispatchCommand CK_VOLUME_UP\n");
+          case GDK_F7:
+              send_request("IrDispatchCommand CK_VOLUME_UP\r\n");
               break;
-          case HILDON_HARDKEY_DECREASE:
-              send_request("IrDispatchCommand CK_VOLUME_DOWN\n");
+          case GDK_F8:
+              send_request("IrDispatchCommand CK_VOLUME_DOWN\r\n");
               break;
-          case HILDON_HARDKEY_FULLSCREEN:
-              send_request("IrDispatchCommand CK_MENU\n");
+          case GDK_F6:
+              send_request("IrDispatchCommand CK_MENU\r\n");
               break;
-          case HILDON_HARDKEY_ESC:
-              send_request("IrDispatchCommand CK_EXIT\n");
+          case GDK_Escape:
+              send_request("IrDispatchCommand CK_EXIT\r\n");
               break;
           default:
               my_printf("%s(): return FALSE\n", __PRETTY_FUNCTION__);
@@ -643,8 +670,7 @@ window_cb_key_press(GtkWidget* widget, GdkEventKey *event)
 static int
 get_display_byte_length()
 {
-    gint ptr, ret;
-    int bytes_length;
+    int bytes_length, ptr, ret;
     
     my_printf("%s()\n", __PRETTY_FUNCTION__);
     ptr=0;
@@ -660,23 +686,25 @@ get_display_byte_length()
       if (ret == -1) {
         hildon_banner_show_information(GTK_WIDGET(window), NULL,
                              "get_response recv failed");
-        close(sockfd);
+        if (sockfd != -1) {
+		close(sockfd);
+		sockfd = -1;
+	}
         return -1;
       }
       
-      ptr += ret;
+      ptr = ret;
 
-    } while (strstr(packet, "GetDisplayData: data bytes:") == NULL
-    		&& strstr(packet, "\n" ) == NULL
-    		&& ptr < sizeof(packet));
+    } while ((strstr(packet, "GetDisplayData: data bytes:") == NULL)
+    		&& (strstr(packet, "\n" ) == NULL)
+    		&& (ptr < sizeof(packet)));
     /* this condition is not ideal, using the ptr check to ensure that the system doesn't
      * loop indefinately while waiting for response, however, it's possible that the
      * loop times out before enough of the message is recieved.
      * It is possible that this could be done in get_response() but that then ties the
      * function into GetDisplayData, also the general idea here was to allow packet to be
      * malloc'd for a suitable size ahead of actually reading the message */
-    		
-    my_printf("%s\n", packet);
+    
     my_printf("%s\n", packet + strlen("GetDisplayData: data bytes: "));
     bytes_length = (int) strtol(packet + strlen("GetDisplayData: data bytes: "), NULL, 0);
 
@@ -700,7 +728,7 @@ setup_display_properties(int bytes_length) {
         display_idx = new_display_idx;
 
         g_object_unref(G_OBJECT(pixbuf));
-        
+
         pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB, FALSE, 8,
                             displays[display_idx].width*HORIZ_SCALE,
                             displays[display_idx].height*VERTICAL_SCALE);
@@ -712,10 +740,10 @@ static gboolean
 connect_to_soundbridge(const gchar *ip_addr)
 {
     struct sockaddr_in dest_addr;   // will hold the destination addr
-    gchar *msg = "GetDisplayData\n";
+    gchar *msg = "GetDisplayData\r\n";
     gchar *screen_data;
     struct timeval tv = {3, 0}; /* 3 sec, 0 usec */
-    
+
     my_printf("%s()\n", __PRETTY_FUNCTION__);
 
     if(!_iap_connected && !_iap_connecting) {
@@ -726,22 +754,28 @@ connect_to_soundbridge(const gchar *ip_addr)
                              "Not connected to network");
       return FALSE;
     }
-    
+
     /* clear out from previous connections */
-    close(sockfd);
+    if (sockfd != -1) {
+	    close(sockfd);
+	    sockfd = -1;
+    }
     clear_pixbuf();
     gtk_frame_set_label(GTK_FRAME(frame), _("Soundbridge Display - Not connected"));
-    
+
     /* make a connection */
     sockfd = socket(PF_INET, SOCK_STREAM, 0);
-    
+
     if (sockfd == -1) {
       hildon_banner_show_information(GTK_WIDGET(window), NULL,
                              "connect_to_soundbridge: Unable to get socket");
-      close(sockfd);
+      if (sockfd != -1) {
+	      close(sockfd);
+	      sockfd = -1;
+      }
       return FALSE;
     }
-    
+
     if (setsockopt(sockfd, SOL_SOCKET, SO_RCVTIMEO, &tv, sizeof(tv)) < 0) {
       hildon_banner_show_information(GTK_WIDGET(window), NULL,
                                      "SO_RCVTIMEO setsockopt error");
@@ -755,19 +789,19 @@ connect_to_soundbridge(const gchar *ip_addr)
     dest_addr.sin_port = htons(DEST_PORT);   // short, network byte order
     dest_addr.sin_addr.s_addr = inet_addr(ip_addr);
     memset(dest_addr.sin_zero, '\0', sizeof dest_addr.sin_zero);
-    
+
     if (connect(sockfd, (struct sockaddr *)&dest_addr, sizeof dest_addr) == -1) {
       hildon_banner_show_information(GTK_WIDGET(window), NULL,
                              "connect_to_soundbridge: Unable to connect");
       close(sockfd);
       return FALSE;
     }
-    
+
     connected = TRUE;
     activity_counter = 0;
-    
+
     has_display = query_type();
-    
+
     if (has_display) {
       /* request a screen update */
       if (send_request(msg) != strlen(msg)) {
@@ -775,25 +809,32 @@ connect_to_soundbridge(const gchar *ip_addr)
                              "connect_to_soundbridge: send failed");
         return FALSE;
       }
-      
-      setup_display_properties(get_display_byte_length());
 
+      setup_display_properties(get_display_byte_length());
+      #if 0
+      /* setup_display_properties eats the screen data, request it again */
+      if (send_request(msg) != strlen(msg)) {
+        hildon_banner_show_information(GTK_WIDGET(window), NULL,
+                             "connect_to_soundbridge: send failed");
+        return FALSE;
+      }
+#endif
       screen_data = get_response("GetDisplayData: data bytes:", 
       					displays[display_idx].offset);
       if (screen_data != NULL) {
-    
+
         my_printf(packet);
-    
+
         update_pixbuf(screen_data);
       }
-    
+
       /* add a polling function */
       g_timeout_add(UPDATE_RATE, periodic_update, NULL);
     } else {
       hildon_banner_show_information(GTK_WIDGET(window), NULL,
                              "No display data available, remote control only");
     }
-    
+
     my_printf("%s(): return TRUE\n", __PRETTY_FUNCTION__);
     return TRUE;
 }
@@ -996,9 +1037,9 @@ menu_cb_connect_scan()
     GtkWidget *dialog = NULL;
     gchar *name, *ip;
     gboolean device_selected = FALSE;
-    
+
     my_printf("%s()\n", __PRETTY_FUNCTION__);
-    
+
     if (!_iap_connected) {
       _iap_connecting = TRUE;
       //osso_iap_connect(OSSO_IAP_ANY, OSSO_IAP_REQUESTED_CONNECT, NULL);
@@ -1007,10 +1048,10 @@ menu_cb_connect_scan()
       gtk_frame_set_label(GTK_FRAME(frame), _("Waiting for connection to scan"));
       return TRUE;
     }
-    
+
     /* make a socket */
     scan_info.sockfd = socket(PF_INET, SOCK_DGRAM, 0);
-    
+
     if (scan_info.sockfd == -1) {
       hildon_banner_show_information(GTK_WIDGET(window), NULL,
                              "menu_cb_connect_scan: Unable to get socket");
@@ -1033,6 +1074,7 @@ menu_cb_connect_scan()
         return FALSE;
     }
 
+
     /* Create the scan dialog */
     dialog = gtk_dialog_new_with_buttons(_("Scan for Soundbridges"),
                                          GTK_WINDOW(window),
@@ -1071,10 +1113,10 @@ menu_cb_connect_scan()
     gtk_tree_view_append_column(GTK_TREE_VIEW(lst_devices), column);
 
     gtk_widget_show_all(dialog);
-    
+
     /* add a polling function */
     g_timeout_add(SCAN_RATE, periodic_scan, NULL);
-    
+
     scan_info.currently_scanning = TRUE;
 
     while (GTK_RESPONSE_OK == gtk_dialog_run(GTK_DIALOG(dialog)))
@@ -1096,8 +1138,11 @@ menu_cb_connect_scan()
     gtk_widget_destroy(dialog);
 
     scan_info.currently_scanning = FALSE;
-    close(scan_info.sockfd);
-    
+    if (scan_info.sockfd != -1) {
+	    close(scan_info.sockfd);
+	    scan_info.sockfd = -1;
+    }
+
     if (device_selected == TRUE) {
       if (connect_to_soundbridge(ip)) {
         add_to_menu(name, ip);
@@ -1107,6 +1152,7 @@ menu_cb_connect_scan()
     my_printf("%s(): return TRUE\n", __PRETTY_FUNCTION__);
     return TRUE;
 }
+
 static gboolean
 menu_cb_connect(gint entry)
 {
@@ -1122,12 +1168,15 @@ menu_cb_connect(gint entry)
     if (ip_addr) {
       if (connected == TRUE) {
         connected = FALSE;
-        close(sockfd);
+        if (sockfd != -1) {
+		close(sockfd);
+		sockfd = -1;
+	}
       }
-      
+
       if (!_iap_connected) {
         gchar *prefix = "Waiting for connection to ", *frame_msg;
-        
+
         _iap_connecting = TRUE;
         //osso_iap_connect(OSSO_IAP_ANY, OSSO_IAP_REQUESTED_CONNECT, NULL);
         con_ic_connection_connect(connection, CON_IC_CONNECT_FLAG_NONE);
@@ -1159,11 +1208,11 @@ menu_cb_connect(gint entry)
         gint result = gtk_dialog_run (GTK_DIALOG(dialog));
         switch (result) {
           GtkWidget *tmp_menu_label;
-          
+
           case GTK_RESPONSE_YES:
             while ((entry+1) < MRU_NUM) {
               gchar *tmp_name, *tmp_addr;
-              
+
               tmp_name = gconf_client_get_string(gconf_client, name_list[entry+1], NULL);
               if (tmp_name) {
                 tmp_addr = gconf_client_get_string(gconf_client, ip_list[entry+1], NULL);
@@ -1325,17 +1374,17 @@ static void my_connection_cb(ConIcConnection *connection,
                              gpointer user_data)
 {
     ConIcConnectionStatus status = con_ic_connection_event_get_status(event);
-    
+
     my_printf("%s()\n", __PRETTY_FUNCTION__);
-    
+
     _iap_connecting = FALSE;
-    
+
     if(status == CON_IC_STATUS_CONNECTED && !_iap_connected) {
       _iap_connected = TRUE;
       if (waiting_reason == WAITING_FOR_SB) {
         gchar *ip_addr=NULL, *name=NULL;
         GConfClient *gconf_client = gconf_client_get_default();
-        
+
         waiting_reason = NOT_WAITING;
         ip_addr = gconf_client_get_string(gconf_client, ip_list[sb_entry], NULL);
         if (ip_addr) {
@@ -1366,58 +1415,9 @@ static void my_connection_cb(ConIcConnection *connection,
       clear_pixbuf();
       my_printf("!iap_connected\n");
     }
-    
-    my_printf("%s(): return\n", __PRETTY_FUNCTION__);
-}
 
-#if 0
-static void
-iap_callback(struct iap_event_t *event, void *arg)
-{
-    my_printf("%s()\n", __PRETTY_FUNCTION__);
-    
-    _iap_connecting = FALSE;
-    my_printf("event->type=0x%x\n", event->type);
-    
-    if(event->type == OSSO_IAP_CONNECTED && !_iap_connected) {
-      _iap_connected = TRUE;
-      if (waiting_reason == WAITING_FOR_SB) {
-        gchar *ip_addr=NULL, *name=NULL;
-        GConfClient *gconf_client = gconf_client_get_default();
-        
-        waiting_reason = NOT_WAITING;
-        ip_addr = gconf_client_get_string(gconf_client, ip_list[sb_entry], NULL);
-        if (ip_addr) {
-          if (connect_to_soundbridge(ip_addr) == TRUE) {
-            name = gconf_client_get_string(gconf_client, name_list[sb_entry], NULL);
-            gtk_frame_set_label(GTK_FRAME(frame), name);
-            move_in_menu(name, ip_addr, sb_entry);
-          } else {
-            gtk_frame_set_label(GTK_FRAME(frame), _("Soundbridge Display - Not connected"));
-          }
-        } else {
-          gtk_frame_set_label(GTK_FRAME(frame), _("Soundbridge Display - Not connected"));
-        }
-      }
-      else if (waiting_reason == WAITING_TO_SCAN) {
-        waiting_reason = NOT_WAITING;
-        menu_cb_connect_scan();
-      }
-      my_printf("iap_connected\n");
-    }
-    
-    if(event->type == OSSO_IAP_DISCONNECTED && _iap_connected) {
-      _iap_connected = FALSE;
-      connected = FALSE;
-      waiting_reason = NOT_WAITING;
-      gtk_frame_set_label(GTK_FRAME(frame), _("Soundbridge Display - Not connected"));
-      clear_pixbuf();
-      my_printf("!iap_connected\n");
-    }
-    
     my_printf("%s(): return\n", __PRETTY_FUNCTION__);
 }
-#endif
 
 gint main(gint argc, gchar *argv[])
 {
@@ -1454,8 +1454,6 @@ gint main(gint argc, gchar *argv[])
 #ifndef ARM /* this doesn't seem to work on the tablet */
     //_iap_connected = TRUE;
 #endif
-
-    //osso_iap_cb(iap_callback);
     
     main_loop = g_main_loop_new(NULL, FALSE);
 
@@ -1464,15 +1462,14 @@ gint main(gint argc, gchar *argv[])
     connection = con_ic_connection_new();
     g_signal_connect(G_OBJECT(connection), "connection-event",
                      G_CALLBACK(my_connection_cb), NULL);
-                     
+
     /* Connect to the internet pre-emptively to prevent lack thereof. */
     if(!_iap_connected && !_iap_connecting)
     {
         _iap_connecting = TRUE;
-        //osso_iap_connect(OSSO_IAP_ANY, OSSO_IAP_REQUESTED_CONNECT, NULL);
         con_ic_connection_connect(connection, CON_IC_CONNECT_FLAG_NONE);
     }
-    
+
     gtk_init(&argc, &argv);
 
     /* Init gconf. */
@@ -1499,7 +1496,7 @@ gint main(gint argc, gchar *argv[])
     screen = gtk_image_new_from_pixbuf(pixbuf);
 
     //gtk_container_add(GTK_CONTAINER(window), screen);
-    
+
     hbox1 = gtk_hbox_new(FALSE, 2);
     hbox2 = gtk_hbox_new(FALSE, 2);
     vbox = gtk_vbox_new(FALSE, 2);
@@ -1520,7 +1517,7 @@ gint main(gint argc, gchar *argv[])
     gtk_container_add(GTK_CONTAINER(vbox), hbox2);
     gtk_container_add(GTK_CONTAINER(frame), screen);
     //gtk_container_add(GTK_CONTAINER(vbox), screen);
-    
+
     /* Create buttons and add them to main view */
     snooze_button = gtk_button_new_with_label(_("Sleep"));
     gtk_container_add(GTK_CONTAINER(hbox1), snooze_button);
@@ -1589,15 +1586,18 @@ gint main(gint argc, gchar *argv[])
                           "IrDispatchCommand CK_BRIGHTNESS\n");
 
     menu_init();
-    
+
     /* soundbridge scan */
     scan_info.progress = 0;
     scan_info.currently_scanning = FALSE;
+    scan_info.sockfd = -1;
+
+    sockfd = -1;
 
     /* Connect signal to X in the upper corner */
     g_signal_connect(G_OBJECT(window), "delete_event",
                      G_CALLBACK(gtk_main_quit), NULL);
-    
+
     g_signal_connect(G_OBJECT(window), "key_press_event",
                      G_CALLBACK(window_cb_key_press), NULL);
 
